@@ -7,7 +7,6 @@ import functools
 import inspect
 import threading
 import time
-import traceback
 import warnings
 import weakref
 from collections import deque
@@ -461,11 +460,12 @@ class Lock:
         try:
             try:
 
-                def aaa(s: Any) -> None:
-                    warnings.warn(f"Lock takes to long {threading.current_thread()}\n{s}, try to cancel...")
+                def aaa(fut: asyncio.Future[Any]) -> None:
+                    # warnings.warn(f"Lock takes to long {threading.current_thread()}\n{s}, try to cancel...")
                     fut.cancel()
 
-                h = fut.get_loop().call_later(120, aaa, "".join(traceback.format_stack()))
+                # h = fut.get_loop().call_later(120, aaa, "".join(traceback.format_stack()))
+                h = fut.get_loop().call_later(120, aaa, fut)
 
                 await fut
 
